/* This file is part of the Imote2 Codeloader.
 *
 * The Imote2 Codeloader is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Imote2 Codeloader is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Imote2 Codeloader. If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * ImoteSerial.java
 *
 * @author Markus Engel
 * Copyright (c) 2009,2010 Networked Systems Group, University of Kaiserslautern
 */
package imote;

import ch.ntb.usb.LibusbJava;
import ch.ntb.usb.Usb_Device;
import ch.ntb.usb.Usb_Device_Descriptor;

/** Serial number and node id of an imote
 */
public class ImoteSerial {
	/** serial number */
	final String serialNumber;
	/** node id */
	final Long nodeId;

	/** setup new serial number info
	 *
	 * @param serialNumber serial number
	 * @param nodeId node id
	 */
	public ImoteSerial(String serialNumber, Long nodeId) {
		this.serialNumber = serialNumber == null ? "" : serialNumber;
		this.nodeId = nodeId;
	}

	/** read info from a connected USB device (hopefully an imote)
	 *
	 * @param device usb device
	 * @param desc usb device descriptor
	 * @return serial number info
	 */
	public static ImoteSerial read(Usb_Device device, Usb_Device_Descriptor desc) {
		long handle = LibusbJava.usb_open(device);
		if (handle != 0) {
			byte serIdx = desc.getISerialNumber();
			if (serIdx != 0) {
				String serial =
					LibusbJava.usb_get_string_simple(handle, serIdx);
				int sep = serial.indexOf(':');
				if (sep == -1) {
					return new ImoteSerial(serial, null);
				}
				long nodeId = Long.parseLong(serial.substring(sep + 1));
				return new ImoteSerial(serial.substring(0, sep), nodeId);
			}
		}
		return new ImoteSerial("", null);
	}

	/** wether the imote fulfils a request for a specific imote description
	 *
	 * @param req request
	 * @return true iff this info fulfils the description
	 */
	public boolean fulfilsRequest(ImoteSerial req) {
		return (req.serialNumber.equals("") ||
			req.serialNumber.equals(req.serialNumber)) &&
			(req.nodeId == null || req.nodeId.equals(this.nodeId));
	}
}
