/* This file is part of the Imote2 Codeloader.
 *
 * The Imote2 Codeloader is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Imote2 Codeloader is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Imote2 Codeloader. If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * Server.java
 *
 * @author Markus Engel
 * Copyright (c) 2009,2010 Networked Systems Group, University of Kaiserslautern
 */
package imote;

import ch.ntb.usb.USB;
import java.rmi.AlreadyBoundException;
import java.rmi.Remote;
import java.rmi.RemoteException;
import java.rmi.registry.LocateRegistry;
import java.rmi.registry.Registry;
import java.rmi.server.UnicastRemoteObject;
import imote.service.RemoteService;

/** Server Role
 */
public class Server implements Role {
	/** rmi port */
	public static final int PORT = 1099;
	/** rmi service */
	public static final String SERVICE = "imote";

	public void start(Configuration config) {
		RemoteService srv = null;
		Registry registry = null;

		USB.init();
		/* setup rmi server and registry */
		try {
			srv = new RemoteService();
			Remote stub = UnicastRemoteObject.exportObject(srv, 0);
			registry = LocateRegistry.createRegistry(PORT);
			registry.bind(SERVICE, stub);
			System.out.println("Created Registry and Service");
		} catch (RemoteException e) {
			System.err.print("RemoteException occurred while "
				+ "exporting service: " + e.toString() + "\n");
			try {
				registry.unbind(SERVICE);
			} catch (Exception ign) {
			}
			try {
				UnicastRemoteObject.unexportObject(srv, true);
			} catch (Exception ign) {
			}
		} catch (AlreadyBoundException e) {
			System.err.print("Service is already bound: " + e.toString());
			try {
				registry.unbind(SERVICE);
			} catch (Exception ign) {
			}
			try {
				UnicastRemoteObject.unexportObject(srv, true);
			} catch (Exception ign) {
			}
		}
	}
}
