/* This file is part of the Imote2 Codeloader.
 *
 * The Imote2 Codeloader is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Imote2 Codeloader is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Imote2 Codeloader. If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * Status.java
 *
 * @author Markus Engel
 * Copyright (c) 2009,2010 Networked Systems Group, University of Kaiserslautern
 */
package imote.communication.rx;

/** Status Definitions */
public enum Status {
	/* these numbers must match the bootloader */
	OK(0),
	ERR_ADDR(1),
	ERR_UNLOCK(2),
	ERR_ERASE(3),
	ERR_PROG(4),
	ERR_UNKNOWN(5),
	/* these are special numbers used for some off-the-protocol status */
	ERR_UNKNOWN_STATUS(200),
	ERR_COMMUNICATION_FAILURE(201);
	/** identifier */
	private final int stat;

	/** setup new status with given identifier
	 *
	 * @param cmd status identifier
	 */
	private Status(int cmd) {
		this.stat = cmd;
	}

	/** get status identifier
	 *
	 * @return identifier
	 */
	public int getStatus() {
		return this.stat;
	}

	/** get status enumeration value from an identifier
	 *
	 * @param stat status identifier
	 * @return status enumeration value
	 */
	public static Status getStatusFromStream(int stat) {
		for (Status s : Status.values()) {
			if (s.getStatus() == stat) {
				return s;
			}
		}
		return ERR_UNKNOWN_STATUS;
	}
}
