/* This file is part of the Imote2 Codeloader.
 *
 * The Imote2 Codeloader is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Imote2 Codeloader is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the Imote2 Codeloader. If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * RemoteService.java
 *
 * @author m_engel
 * Copyright (c) 2009,2010 Networked Systems Group, University of Kaiserslautern
 */
package imote.service;

import ch.ntb.usb.USBException;
import imote.ImoteDescription;
import imote.communication.Imote;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import java.util.List;

/** Remote Service */
public class RemoteService implements ServiceInterface {
	private ImoteInterface imote = null;

	public ImoteInterface getImote(int vendorId, int productId,
		String serialNumber, Long nodeId) throws RemoteException, USBException {
		System.out.println("Imote Service Requested");

		if (this.imote != null) {
			this.closeImote();
		}

		/* Try to get Imote */
		this.imote = Imote.getImote(vendorId, productId, serialNumber, nodeId);
		if (this.imote == null) {
			/* returned null => not found */
			return null;
		}

		System.out.println("Imote connected, exporting");

		return (ImoteInterface) UnicastRemoteObject.exportObject(this.imote, 0);
	}

	public void closeImote() throws RemoteException {
		if (this.imote != null) {
			System.out.println("Closing Imote, unexporting Object");
			try {
				this.imote.close();
				UnicastRemoteObject.unexportObject(this.imote, true);
			} finally {
				this.imote = null;
			}
		}
	}

	public List<ImoteDescription> getConnectedImotes(int vendorId,
		int productId) throws RemoteException, USBException {
		return Imote.getConnectedImotes(vendorId, productId);
	}
}
